wallaroo.wallaroo_ml_ops_api_client.models.features_list_response_200 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.features_list_response_200

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5from ..models.features_list_response_200_features import \
     6    FeaturesListResponse200Features
     7
     8T = TypeVar("T", bound="FeaturesListResponse200")
     9
    10@attr.s(auto_attribs=True)
    11class FeaturesListResponse200:
    12    """
    13    Attributes:
    14        features (FeaturesListResponse200Features):
    15        name (str):
    16        is_auth_enabled (bool):
    17    """
    18
    19    features: FeaturesListResponse200Features
    20    name: str
    21    is_auth_enabled: bool
    22    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    23
    24
    25    def to_dict(self) -> Dict[str, Any]:
    26        features = self.features.to_dict()
    27
    28        name = self.name
    29        is_auth_enabled = self.is_auth_enabled
    30
    31        field_dict: Dict[str, Any] = {}
    32        field_dict.update(self.additional_properties)
    33        field_dict.update({
    34            "features": features,
    35            "name": name,
    36            "is_auth_enabled": is_auth_enabled,
    37        })
    38
    39        return field_dict
    40
    41
    42
    43    @classmethod
    44    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    45        d = src_dict.copy()
    46        features = FeaturesListResponse200Features.from_dict(d.pop("features"))
    47
    48
    49
    50
    51        name = d.pop("name")
    52
    53        is_auth_enabled = d.pop("is_auth_enabled")
    54
    55        features_list_response_200 = cls(
    56            features=features,
    57            name=name,
    58            is_auth_enabled=is_auth_enabled,
    59        )
    60
    61        features_list_response_200.additional_properties = d
    62        return features_list_response_200
    63
    64    @property
    65    def additional_keys(self) -> List[str]:
    66        return list(self.additional_properties.keys())
    67
    68    def __getitem__(self, key: str) -> Any:
    69        return self.additional_properties[key]
    70
    71    def __setitem__(self, key: str, value: Any) -> None:
    72        self.additional_properties[key] = value
    73
    74    def __delitem__(self, key: str) -> None:
    75        del self.additional_properties[key]
    76
    77    def __contains__(self, key: str) -> bool:
    78        return key in self.additional_properties

@attr.s(auto_attribs=True)
class FeaturesListResponse200: View Source

    11@attr.s(auto_attribs=True)
    12class FeaturesListResponse200:
    13    """
    14    Attributes:
    15        features (FeaturesListResponse200Features):
    16        name (str):
    17        is_auth_enabled (bool):
    18    """
    19
    20    features: FeaturesListResponse200Features
    21    name: str
    22    is_auth_enabled: bool
    23    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    24
    25
    26    def to_dict(self) -> Dict[str, Any]:
    27        features = self.features.to_dict()
    28
    29        name = self.name
    30        is_auth_enabled = self.is_auth_enabled
    31
    32        field_dict: Dict[str, Any] = {}
    33        field_dict.update(self.additional_properties)
    34        field_dict.update({
    35            "features": features,
    36            "name": name,
    37            "is_auth_enabled": is_auth_enabled,
    38        })
    39
    40        return field_dict
    41
    42
    43
    44    @classmethod
    45    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    46        d = src_dict.copy()
    47        features = FeaturesListResponse200Features.from_dict(d.pop("features"))
    48
    49
    50
    51
    52        name = d.pop("name")
    53
    54        is_auth_enabled = d.pop("is_auth_enabled")
    55
    56        features_list_response_200 = cls(
    57            features=features,
    58            name=name,
    59            is_auth_enabled=is_auth_enabled,
    60        )
    61
    62        features_list_response_200.additional_properties = d
    63        return features_list_response_200
    64
    65    @property
    66    def additional_keys(self) -> List[str]:
    67        return list(self.additional_properties.keys())
    68
    69    def __getitem__(self, key: str) -> Any:
    70        return self.additional_properties[key]
    71
    72    def __setitem__(self, key: str, value: Any) -> None:
    73        self.additional_properties[key] = value
    74
    75    def __delitem__(self, key: str) -> None:
    76        del self.additional_properties[key]
    77
    78    def __contains__(self, key: str) -> bool:
    79        return key in self.additional_properties

Attributes: features (FeaturesListResponse200Features): name (str): is_auth_enabled (bool):

FeaturesListResponse200( features: wallaroo.wallaroo_ml_ops_api_client.models.features_list_response_200_features.FeaturesListResponse200Features, name: str, is_auth_enabled: bool) View Source

    2def __init__(self, features, name, is_auth_enabled):
    3    self.features = features
    4    self.name = name
    5    self.is_auth_enabled = is_auth_enabled
    6    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class FeaturesListResponse200.

def to_dict(self) -> Dict[str, Any]: View Source

    26    def to_dict(self) -> Dict[str, Any]:
    27        features = self.features.to_dict()
    28
    29        name = self.name
    30        is_auth_enabled = self.is_auth_enabled
    31
    32        field_dict: Dict[str, Any] = {}
    33        field_dict.update(self.additional_properties)
    34        field_dict.update({
    35            "features": features,
    36            "name": name,
    37            "is_auth_enabled": is_auth_enabled,
    38        })
    39
    40        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    44    @classmethod
    45    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    46        d = src_dict.copy()
    47        features = FeaturesListResponse200Features.from_dict(d.pop("features"))
    48
    49
    50
    51
    52        name = d.pop("name")
    53
    54        is_auth_enabled = d.pop("is_auth_enabled")
    55
    56        features_list_response_200 = cls(
    57            features=features,
    58            name=name,
    59            is_auth_enabled=is_auth_enabled,
    60        )
    61
    62        features_list_response_200.additional_properties = d
    63        return features_list_response_200

additional_keys: List[str]